==> qtjambi-remoteobjects-5.15.14-sources.jar: io/qt/remoteobjects/QConnectionAbstractServer.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QConnectionAbstractServer</p>
 */
public abstract class QConnectionAbstractServer extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QConnectionAbstractServer.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QConnectionAbstractServer {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@NonNull QUrl address(){
            return address_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QUrl address_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public void close(){
            close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void close_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected io.qt.remoteobjects.@Nullable ServerIoDevice configureNewConnection(){
            return configureNewConnection_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.remoteobjects.ServerIoDevice configureNewConnection_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public boolean hasPendingConnections(){
            return hasPendingConnections_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native boolean hasPendingConnections_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public boolean listen(io.qt.core.@NonNull QUrl address){
            return listen_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(address));
        }
        @QtUninvokable
        private native boolean listen_native_cref_QUrl(long __this__nativeId, long address);
        
        
        @Override
        @QtUninvokable
        public io.qt.network.QAbstractSocket.@NonNull SocketError serverError(){
            return io.qt.network.QAbstractSocket.SocketError.resolve(serverError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
        }
        @QtUninvokable
        private native int serverError_native_constfct(long __this__nativeId);
        
    }
    

    public final @NonNull Signal0 newConnection = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QConnectionAbstractServer() {
        this((io.qt.core.QObject)null);
    }
    
    public QConnectionAbstractServer(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QConnectionAbstractServer instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public final io.qt.remoteobjects.@Nullable ServerIoDevice nextPendingConnection(){
        return nextPendingConnection_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.remoteobjects.ServerIoDevice nextPendingConnection_native(long __this__nativeId);
    
    @QtUninvokable
    public abstract io.qt.core.@NonNull QUrl address();
    
    @QtUninvokable
    private native io.qt.core.QUrl address_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public abstract void close();
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    @QtUninvokable
    protected abstract io.qt.remoteobjects.@Nullable ServerIoDevice configureNewConnection();
    
    @QtUninvokable
    private native io.qt.remoteobjects.ServerIoDevice configureNewConnection_native(long __this__nativeId);
    
    @QtUninvokable
    public abstract boolean hasPendingConnections();
    
    @QtUninvokable
    private native boolean hasPendingConnections_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public abstract boolean listen(io.qt.core.@NonNull QUrl address);
    
    @QtUninvokable
    private native boolean listen_native_cref_QUrl(long __this__nativeId, long address);
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public abstract io.qt.network.QAbstractSocket.@NonNull SocketError serverError();
    
    @QtUninvokable
    private native int serverError_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QConnectionAbstractServer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QConnectionAbstractServer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QConnectionAbstractServer instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-5.15.16-sources.jar: io/qt/remoteobjects/QConnectionAbstractServer.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QConnectionAbstractServer</code></p>
 */
public abstract class QConnectionAbstractServer extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QConnectionAbstractServer.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QConnectionAbstractServer {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@NonNull QUrl address(){
            return address_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QUrl address_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public void close(){
            close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void close_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected io.qt.remoteobjects.@Nullable ServerIoDevice configureNewConnection(){
            return configureNewConnection_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.remoteobjects.ServerIoDevice configureNewConnection_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public boolean hasPendingConnections(){
            return hasPendingConnections_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native boolean hasPendingConnections_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public boolean listen(io.qt.core.@NonNull QUrl address){
            return listen_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(address));
        }
        @QtUninvokable
        private native boolean listen_native_cref_QUrl(long __this__nativeId, long address);
        
        
        @Override
        @QtUninvokable
        public io.qt.network.QAbstractSocket.@NonNull SocketError serverError(){
            return io.qt.network.QAbstractSocket.SocketError.resolve(serverError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
        }
        @QtUninvokable
        private native int serverError_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>newConnection()</code></p>
     */
    public final @NonNull Signal0 newConnection = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QConnectionAbstractServer(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QConnectionAbstractServer() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>QConnectionAbstractServer(QObject*)</code></p>
     */
    public QConnectionAbstractServer(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QConnectionAbstractServer instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>nextPendingConnection()</code></p>
     */
    @QtUninvokable
    public final io.qt.remoteobjects.@Nullable ServerIoDevice nextPendingConnection(){
        return nextPendingConnection_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.remoteobjects.ServerIoDevice nextPendingConnection_native(long __this__nativeId);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>address()const</code></p>
     */
    @QtUninvokable
    public abstract io.qt.core.@NonNull QUrl address();
    
    @QtUninvokable
    private native io.qt.core.QUrl address_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>close()</code></p>
     */
    @QtUninvokable
    public abstract void close();
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>configureNewConnection()</code></p>
     */
    @QtUninvokable
    protected abstract io.qt.remoteobjects.@Nullable ServerIoDevice configureNewConnection();
    
    @QtUninvokable
    private native io.qt.remoteobjects.ServerIoDevice configureNewConnection_native(long __this__nativeId);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>hasPendingConnections()const</code></p>
     */
    @QtUninvokable
    public abstract boolean hasPendingConnections();
    
    @QtUninvokable
    private native boolean hasPendingConnections_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>listen(QUrl)</code></p>
     */
    @QtUninvokable
    public abstract boolean listen(io.qt.core.@NonNull QUrl address);
    
    @QtUninvokable
    private native boolean listen_native_cref_QUrl(long __this__nativeId, long address);
    
    /**
     * <p>See <code>QConnectionAbstractServer::<wbr>serverError()const</code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public abstract io.qt.network.QAbstractSocket.@NonNull SocketError serverError();
    
    @QtUninvokable
    private native int serverError_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QConnectionAbstractServer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QConnectionAbstractServer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QConnectionAbstractServer instance, QDeclarativeConstructor constructor);
    
}
